@@ -2,8 +2,9 @@ from __future__ import annotations
 
 import logging
 from enum import Enum
-from typing import Dict, Optional, Type
+from typing import Any, Dict, Optional, Type
 
+import ujson
 from pydantic import BaseConfig, BaseModel, Field
 
 logger = logging.getLogger('BaseObject')
@@ -12,12 +13,14 @@ logger = logging.getLogger('BaseObject')
 class BaseObject(BaseModel):
     class Config(BaseConfig):
         anystr_strip_whitespace = True
-        validate_assignment = True
         underscore_attrs_are_private = True
         use_enum_values = True
+        json_dumps = ujson.dumps
+        json_loads = ujson.loads
 
     _all: Optional[Dict[str, Type[BaseObject]]] = {}
     ID: str = Field(..., alias='@type')
+    EXTRA: Optional[dict[str, Any]] = Field({}, alias='@extra')
 
     @staticmethod
     def read(data: dict):
@@ -30,7 +33,6 @@ class BaseObject(BaseModel):
         q_type = data.get('@type')
 
         if not bool(q_type):
-            logger.warning(f'@type not found in received update. {data}')
             return data
 
         q_type = q_type.value if isinstance(q_type, Enum) else q_type
@@ -40,7 +42,18 @@ class BaseObject(BaseModel):
             logger.error(f'Object class not found for @type={q_type}')
             return data
 
-        for key, value in data.items():
-            data[key] = value if key == '@extra' else BaseObject.read(value)
+        processed_data = {}
 
-        return object_class.read(data)
+        for key, value in data.items():
+            # Workaround for BaseModel.construct(**kwargs).
+            # It doesn't automatically rename fields according to aliases
+            if key in ['json', 'filter', 'type', 'hash']:
+                key = key + "_"
+            elif key == '@extra':
+                key = 'EXTRA'
+
+            processed_data[key] = BaseObject.read(value)
+
+        del data
+
+        return object_class.read(processed_data)
